package com.tzld.piaoquan.risk.control.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.tzld.piaoquan.risk.control.common.base.CommonResponse;
import com.tzld.piaoquan.risk.control.config.QywxConfig;
import com.tzld.piaoquan.risk.control.model.qywx.QwCommonResModel;
import com.tzld.piaoquan.risk.control.model.qywx.QwLoginCheckCode;
import com.tzld.piaoquan.risk.control.model.qywx.QwLoginQRCodeModel;
import com.tzld.piaoquan.risk.control.service.QwLoginService;
import com.tzld.piaoquan.risk.control.util.HttpClientUtil;
import com.tzld.piaoquan.risk.control.util.HttpPoolClient;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

@RestController
@RequestMapping("/qw")
@Slf4j
public class QwLoginController {
    private static final HttpPoolClient httpPoolClientDefault = HttpClientUtil.create(10000, 10000, 2000, 5000, 5, 10000);
    @Autowired
    private QywxConfig qywxConfig; // 注入配置类
    @Autowired
    private QwLoginService qwLoginService;
    private static final Logger LOGGER = LoggerFactory.getLogger(QwLoginController.class);


    @PostMapping("/getQrCode")
    public CommonResponse<QwLoginQRCodeModel> getQrCode(@RequestBody Map<String, String> request) {
        String phoneNumber = request.get("phoneNumber");
        QwCommonResModel<QwLoginQRCodeModel> loginModel = qwLoginService.getLoginQRCode(phoneNumber);
        return CommonResponse.success(loginModel.getData());
    }

    @PostMapping("/checkQRCode")
    public CommonResponse<String> checkQRCode(@RequestBody QwLoginCheckCode checkCode) {
        int ret = qwLoginService.checkQRCode(checkCode);
        if(ret == 0) {
            return CommonResponse.success();
        } else {
            LOGGER.error("checkQRCode failed, ret: {}", ret);
            return CommonResponse.error("failed");
        }
    }

    @PostMapping("/automaticLogin")
    public CommonResponse<String> automaticLogin(@RequestBody QwLoginCheckCode checkCode) {
        String url = qywxConfig.getDomain() + qywxConfig.getPath("login-qrcode");
        String response =  httpPoolClientDefault.postJson(url, JSON.toJSONString(checkCode)).toString();
        System.out.println("checkQRCode,response: " + response);
        return CommonResponse.success();
    }

    @PostMapping("/quiteQwLogin")
    public CommonResponse<String> quiteQwLogin(@RequestBody String uuid) {
        String url = qywxConfig.getDomain() + qywxConfig.getPath("quit-login");
        String response =  httpPoolClientDefault.postJson(url, uuid).toString();
        log.info("quiteLogin,response: {}", response);
        QwCommonResModel<QwLoginQRCodeModel> QRCODE = JSON.parseObject(response, new TypeReference<QwCommonResModel<QwLoginQRCodeModel>>() {});
        return CommonResponse.success();

    }

    @PostMapping("/checkLogin")//前端轮训检测是否登录成功
    public CommonResponse<String> checkLogin(@RequestBody String uuid) {
        if(true) {
            return new CommonResponse<>();
        } else if(false) {
            return CommonResponse.success();
        } else {
            return CommonResponse.success();
        }
//        String url = Constant.QWDOMAIN + Constant.LOGIN_QRCODE_PATH;
//        String response =  httpPoolClientDefault.postJson(url, uuid).toString();
//        QwLoginQRCodeModel QRCODE = JSON.parseObject(response, QwLoginQRCodeModel.class);
//        return CommonResponse.success("ok");
    }
    @PostMapping("/getRunClients")//获取运行中的实例
    public CommonResponse<String> getRunClients() {
        return CommonResponse.success(qwLoginService.getRunClients());
    }

}
